/**
 * 动态图标Hooks
 * @author andy
 */
import { onMounted, onBeforeUnmount, ref } from 'vue'
import * as echarts from 'echarts'
import elementResizeDetectorMaker from 'element-resize-detector'

export function useEcharts(el, options) {
    let chartEl
    let chartRef = ref(null)
    let erd = elementResizeDetectorMaker()
    const resizeHandle = () => {
        chartEl && chartEl.resize()
    }

    onMounted(() => {
        if(el?.value) {
            chartEl = echarts.init(el.value)
            chartEl.setOption(options)
            chartRef.value = chartEl
        }
        erd.listenTo(el.value, resizeHandle)
    })
    onBeforeUnmount(() => {
        chartEl.dispose()
        erd.removeListener(el.value, resizeHandle)
    })
    return chartRef
}
