/**
 * 路由管理Router
 * @author andy
 */
import { createRouter, createWebHashHistory } from 'vue-router'
import { authState } from '@/pinia/modules/auth'
import Layout from '@/layouts/index.vue'
import { loginWindow } from '@/windows/actions'
// 批量导入路由
const modules = import.meta.glob('./modules/*.js', { eager: true })
// console.log(modules)
const patchRouters = Object.keys(modules).map(key => modules[key].default).flat()
// console.log(patchRouters)

const routes = [
    {
        path: '/', redirect: '/desktop',
    },
    ...patchRouters,
    // 错误模块
    {
        path: '/:pathMatch(.*)*',
        redirect: '/404',
        component: Layout,
        meta: {
            title: '404 error',
        },
        children: [
            {
                path: '404',
                component: () => import('@/views/error/404.vue'),
            }
        ]
    },
]
const router = createRouter({
    history: createWebHashHistory(),
    routes,
})
router.beforeEach((to, from) => {
    const authstate = authState()
    // 登录验证
    if(to?.meta?.requireAuth && !authstate.authorization) {
        loginWindow()
    }
})

router.afterEach(() => {})

router.onError(error => {
    console.warn('[Router Error]', error)
})
export default router
