/**
 * 主路由模块
 * @author andy
 */
import Desktop from '@/layouts/desktop.vue'
import Layout from '@/layouts/index.vue'
import Blank from '@/layouts/blank.vue'
export default [
  // 桌面模块
  {
    path: '/desktop',
    component: Desktop,
    meta: {
      title: '桌面',
      requireAuth: true, // 需验证
    }
  },

  {
    path: '/home',
    component: Layout,
    meta: {
      title: '首页',
      requireAuth: true, // 需验证
    },
    children: [
      {
        // 默认'/home'路由，类似react路由配置index:true
        path: '',
        component: () => import('@/views/home/index.vue'),
        meta: {
          title: '首页',
        },
      },
      {
        path: 'dashboard',
        component: () => import('@/views/home/dashboard.vue'),
        meta: {
          title: '工作台',
        },
      },
    ]
  },
  {
    path: '/components',
    redirect: '/components/table',
    component: Layout,
    meta: {
      title: '组件',
      requireAuth: true, // 需验证
    },
    children: [
      // 表格
      {
        path: 'table',
        redirect: '/components/table/all',
        component: Blank,
        meta: {
          title: '表格',
        },
        children: [
          {
            path: 'all',
            component: () => import('@/views/components/table/all.vue'),
            meta: {
              title: '表格',
            },
          },
          {
            path: 'search',
            component: () => import('@/views/components/table/search.vue'),
            meta: {
              title: '搜索表格',
            },
          },
        ]
      },
      // 列表
      {
        path: 'list',
        component: () => import('@/views/components/list/index.vue'),
        meta: {
          title: '列表',
        },
      },
      // 表单
      {
        path: 'form',
        redirect: '/components/form/all',
        component: Blank,
        meta: {
          title: '表单',
        },
        children: [
          {
            path: 'all',
            component: () => import('@/views/components/form/all.vue'),
            meta: {
              title: '所有表单',
            },
          },
        ]
      },
      // markdown编辑器
      {
        path: 'markdown',
        component: () => import('@/views/components/markdown/index.vue'),
        meta: {
          title: '编辑器',
        },
      },
    ]
  },

// 用户管理
  {
    path: '/user',
    component: Layout,
    meta: {
      title: '用户管理',
    },
    children: [
      {
        path: '',
        component: () => import('@/views/user/index.vue'),
        meta: {
          title: '用户管理',
        },
      },
      {
        path: 'role',
        component: () => import('@/views/user/role.vue'),
        meta: {
          title: '角色管理',
        },
      },
      {
        path: 'department',
        component: () => import('@/views/user/department.vue'),
        meta: {
          title: '部门管理',
        },
      },
    ]
  },

  // 设置模块
  {
    path: '/setting',
    component: Layout,
    meta: {
      title: '设置',
    },
    children: [
      {
        path: '',
        component: () => import('@/views/setting/index.vue'),
        meta: {
          title: '用户中心',
        },
      },
      {
        path: 'logs',
        component: () => import('@/views/setting/logs.vue'),
        meta: {
          title: '日志管理',
        },
      },
      {
        path: 'system',
        redirect: '/setting/system/website',
        component: Blank,
        meta: {
          title: '网站管理',
        },
        children: [
          {
            path: 'website',
            component: () => import('@/views/setting/system/index.vue'),
            meta: {
              title: '网站设置'
            }
          },
          {
            path: 'mail',
            component: () => import('@/views/setting/system/mail.vue'),
            meta: {
              title: '邮件服务'
            }
          }
        ]
      },
    ]
  },

  // 错误模块
  {
    path: '/error',
    component: Layout,
    meta: {
      title: '错误页'
    },
    children: [
      {
        path: '403',
        component: () => import('@/views/error/403.vue'),
        meta: {
          title: '403error'
        },
      },
      {
        path: '404',
        component: () => import('@/views/error/404.vue'),
        meta: {
          title: '404error'
        },
      }
    ]
  },
]
