import { appState } from '@/pinia/modules/app'
import { authState } from '@/pinia/modules/auth'
// 初始化渲染进程
export async function launchApp() {
    return new Promise(resolve => window.electron.once('win-loaded', async(event, args) => resolve(args)))
}

export function winCreate(args) {
    window.electron.send('win-create', args)
}

/**
 * 设置窗口
 * @param {string} type 窗口事件类型(show|hide|minimize|maximize|restore|reload|max2min|close)
 * @param {number} id 窗口id
 */
export function winSet(type, id) {
    window.electron.send('win-set', {
        action: type,
        id: id
    })
}
/**
 * 主/渲染进程传递数据
 * @param {object} args 传递数据 {type: 'xxx', value: 666, ....}
 */
export function winIpcData(args) {
    window.electron.send('win-ipcdata', args)
}

export function winTrayFlash(bool) {
    window.electron.send('win-trayflash', bool)
}

// 登录窗口
export function loginWindow() {
    winCreate({
        url: '/login', title: '登录',
        width: 750, height: 480,
        isMajor: true, resizable: false, maximizable: false, alwaysOnTop: true
    })
}

// 关于窗口
export function aboutWindow() {
    winCreate({
        url: '/win/about', title: '关于',
        width: 375, height: 300,  minWidth: 375, minHeight: 300,
        resizable: false, alwaysOnTop: true,
    })
}
export function settingWindow() {
    winCreate({
        url: '/win/setting',title: '设置',
        width: 550,height: 470,
        resizable: false, maximizable: false,
    })
}
export function skinWindow() {
    winCreate({
        url: '/win/skin',title: '换肤',
        width: 360, height: 480,
        resizable: false, maximizable: false,
        show: true,
    })
}
/**
 * 监听主/渲染进程通信(共用监听每个页面通信)
 */
export function ipcLoaded() {
    const appstate = appState()
    const authstate = authState()
    window.electron.on('win-ipcdata', (e, data) => {
        const { type, value } = data
        switch (type) {
            case 'WINIPC_LOGOUT':
                authstate.$reset()
                appstate.$reset()
                break;
            // 更新pinia/app.js配置
            case 'WINIPC_UPDATECONFIG':
                const { key, data } = value
                appstate.updateConfig(key, data)
                break;
            case 'WINIPC_ABOUTWIN':
                aboutWindow()
                break;
            case 'WINIPC_SETTINGWIN':
                settingWindow()
                break;
            case 'WINIPC_SKINWIN':
                skinWindow()
                break;
            default:
                break;
        }
    })
}
